@@ -95,6 +95,8 @@ public class StackTraceSnapshotBuilder {
         new MethodInfo("sun.print.Win32PrintServiceLookup","notifyPrinterChange(long) : int"), // NOI18N
         new MethodInfo("java.net.DualStackPlainSocketImpl","waitForConnect[native]"), // NOI18N
         new MethodInfo("java.net.DualStackPlainSocketImpl","waitForConnect(int, int) : void"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueueArrayWrapper","kevent0[native]"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueueArrayWrapper","kevent0(int, long, int, long) : int"), // NOI18N
     });
 
     private InstrumentationFilter filter;
