@@ -43,20 +43,21 @@
 
 package org.netbeans.lib.profiler.server;
 
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.lang.reflect.Method;
+import java.net.URL;
+import java.text.MessageFormat;
+import java.util.LinkedHashMap;
+import java.util.ResourceBundle;
+import java.util.WeakHashMap;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.global.Platform;
 import org.netbeans.lib.profiler.global.ProfilingSessionStatus;
 import org.netbeans.lib.profiler.global.TransactionalSupport;
 import org.netbeans.lib.profiler.server.system.*;
 import org.netbeans.lib.profiler.wireprotocol.*;
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.lang.reflect.Method;
-import java.text.MessageFormat;
-import java.util.LinkedHashMap;
-import java.util.ResourceBundle;
-import java.util.WeakHashMap;
 
 
 /**
@@ -179,6 +180,18 @@ public class ProfilerInterface implements CommonConstants {
                 e.printStackTrace(System.err);
             }
 
+            if (Platform.getJDKVersionNumber() == CommonConstants.JDK_19) {
+                try {
+                    // preload classes for classLoadHook()
+                    Class.forName("java.lang.reflect.WeakPairMap$Pair"); // NOI18N
+                    Class.forName("java.lang.reflect.WeakPairMap$WeakRefPeer");    // NOI18N
+                    Class.forName("java.lang.reflect.WeakPairMap$Pair$Weak"); // NOI18N
+                    Class.forName("java.lang.reflect.WeakPairMap$Pair$Weak$1"); // NOI18N
+                } catch (ClassNotFoundException e) {
+                    e.printStackTrace(System.err);
+                }
+            }
+            
             // The following code is needed to enforce native method bind for Thread.sleep before instrumentation, so
             // that the NativeMethodBind it can be disabled as first thing in instrumentation
             // this is needed as a workaround for JDK bug:
@@ -286,7 +299,7 @@ public class ProfilerInterface implements CommonConstants {
     }
 
     // TODO [release]: change value to FALSE to remove the print code below entirely by compiler
-    private static final boolean DEBUG = System.getProperty("org.netbeans.lib.profiler.server.ProfilerInterface.classLoadHook") != null; // NOI18N
+    private static final boolean DEBUG = Boolean.getBoolean("org.netbeans.lib.profiler.server.ProfilerInterface.classLoadHook"); // NOI18N
     private static final boolean INSTRUMENT_JFLUID_CLASSES = Boolean.getBoolean("org.netbeans.lib.profiler.server.instrumentJFluidClasses"); // NOI18N
 
     // The lock used to serialize requests from server to client. May be used outside this class.
@@ -294,7 +307,6 @@ public class ProfilerInterface implements CommonConstants {
     private static ProfilerServer profilerServer;
     private static ProfilingSessionStatus status;
     private static EventBufferManager evBufManager;
-    private static ClassLoader scl;
     private static Class[] loadedClassesArray; // Temporary array, used to send all loaded class names to client
                                                // on instrumentation initiation.
     private static int[] loadedClassesLoaders; // Ditto, for loaders
@@ -516,8 +528,7 @@ public class ProfilerInterface implements CommonConstants {
         Threads.initialize();
         HeapDump.initialize(Platform.getJDKVersionNumber() == Platform.JDK_15);
         ClassLoaderManager.initialize(profilerServer);
-        scl = ClassLoader.getSystemClassLoader();
-        ClassLoaderManager.addLoader(scl);
+        ClassLoaderManager.addLoader(ClassLoader.getSystemClassLoader());
         reflectMethods = new WeakHashMap();
 
         evBufManager = new EventBufferManager(profilerServer);
@@ -793,6 +804,16 @@ public class ProfilerInterface implements CommonConstants {
                     if (dynamic) {
                         if (loadedClassesLoaders[i] > 0) { // bootstrap classloader has index -1 and system classloader has index 0
                             nonSystemClasses[nonSystemIndex++] = clazz;
+                        } else {    // system or bootstrap class loader
+                            String name = clazz.getName();
+                            
+                            if (name.startsWith("[") || internalClassName(name)) {  // NOI18N
+                                continue;
+                            }
+                            if (ClassBytesLoader.getClassFileURL(name) == null) {
+                                // system class without file on disk -> must be cached
+                                nonSystemClasses[nonSystemIndex++] = clazz;
+                            }
                         }
                         if (nonSystemIndex == MAX_CLASSES) {
                             cacheLoadedClasses(nonSystemClasses,nonSystemIndex);
@@ -966,23 +987,7 @@ public class ProfilerInterface implements CommonConstants {
                             resumeTimer = true; // resume blackout period at the end
                         }
 
-                        // Get cached class file bytes if they are available, i.e. if the class is loaded by a custom classloader
-                        // If remote profiling is used, get these class file bytes from system classpath
-                        // classLoaderId = 0 means that it is a system or bootstrap classloader
-                        byte[] classFileBytes = null;
-                        if (classLoaderId > 0) {
-                            classFileBytes = Classes.getCachedClassFileBytes(clazz);
-                            if (classFileBytes == null) {
-                                if (DEBUG) {
-                                    System.err.println("Cannot get classbytes for "+clazz.getName()+" loader "+classLoaderId);
-                                }
-                                cacheLoadedClass(clazz);
-                                classFileBytes = getCachedClassFileBytes(clazz);
-                            }
-                        } else if (status.remoteProfiling) {
-                            classFileBytes = ClassBytesLoader.getClassFileBytes(className);
-                        }
-
+                        byte[] classFileBytes = getClassFileBytes(clazz, classLoaderId);
                         // send request to tool to instrument the bytecode
                         ClassLoadedCommand cmd = new ClassLoadedCommand(className,
                                                                         ClassLoaderManager.getThisAndParentLoaderData(classLoaderId),
@@ -1096,6 +1101,8 @@ public class ProfilerInterface implements CommonConstants {
     }
 
     private static int firstTimeVMObjectAlloc(String className, int classLoaderId) {
+        GetClassIdResponse resp;
+
         if (internalClassName(className)) {
             return -1;
         }
@@ -1110,17 +1117,20 @@ public class ProfilerInterface implements CommonConstants {
 
             GetClassIdCommand cmd = new GetClassIdCommand(className, classLoaderId);
             profilerServer.sendComplexCmdToClient(cmd);
-
-            GetClassIdResponse resp = (GetClassIdResponse) profilerServer.getLastResponse();
-
-            if (resp.isOK()) {
-                return resp.getClassId();
-            }
-
-            return -1;
-        } finally {
+            resp = (GetClassIdResponse) profilerServer.getLastResponse();
+        }  finally {
             serialClientOperationsLock.endTrans();
         }
+        if (resp.isOK()) {
+            int classId = resp.getClassId();
+            int instrClasses = classId+1;
+            if (instrClasses > status.getNInstrClasses()) {
+                status.updateAllocatedInstancesCountInfoInServer(instrClasses);
+                ProfilerRuntimeMemory.setAllocatedInstancesCountArray(status.getAllocatedInstancesCount());
+            }
+            return classId;
+        }
+        return -1;
     }
 
     private static void handleFakeInitRecursiveInstrumentationCommand() {
@@ -1180,7 +1190,8 @@ public class ProfilerInterface implements CommonConstants {
                             // to server
                             if (instrClassLoaders[i] == 0) {
                                 b[k] = ClassBytesLoader.getClassFileBytes(instrClassNames[i]);
-                            } else {
+                            }
+                            if (b[k] == null) {
                                 b[k] = getCachedClassFileBytes(clazzes[k]);
                             }
                         }
@@ -1296,6 +1307,8 @@ public class ProfilerInterface implements CommonConstants {
                                                      // we try to profile PetStore with eager instrumentation scheme on Sun ONE AS 7. This makes the problem go away,
                                                      // but its root cause is still unclear to me.
                || name.equals("com.sun.enterprise.J2EESecurityManager") // NOI18N
+               // do not instrument classes created by Unsafe.defineAnonymousClass() 
+               || name.contains("/") // NOI18N   
         );
     }
 
@@ -1384,6 +1397,35 @@ public class ProfilerInterface implements CommonConstants {
         Classes.cacheLoadedClasses(nonSystemClasses,nonSystemIndex);
     }
 
+    /* Get class file bytes if they are available, i.e. if the class is loaded by a custom classloader
+    * If remote profiling is used, get these class file bytes from system classpath
+    * classLoaderId = 0 means that it is a system or bootstrap classloader
+    */
+    private static byte[] getClassFileBytes(Class clazz, int classLoaderId) {
+        byte[] classFileBytes = null;
+        URL classURL = null;
+        
+        if (classLoaderId > 0 || (classURL = ClassBytesLoader.getClassFileURL(clazz.getName())) == null) {
+            classFileBytes = Classes.getCachedClassFileBytes(clazz);
+            if (classFileBytes == null) {
+                if (DEBUG) {
+                    System.err.println("Cannot get classbytes for "+clazz.getName()+" loader "+classLoaderId);
+                }
+                cacheLoadedClass(clazz);
+                classFileBytes = getCachedClassFileBytes(clazz);
+                if (classFileBytes == null) {
+                    if (Platform.getJDKVersionNumber() != Platform.JDK_CVM) {
+                        System.err.println("***Profiler agent warning: could not get .class file for a synthetic class " + clazz.getName()
+                                           + " in ProfilerInterface.getClassFileBytes"); // NOI18N
+                    }
+                }
+            }
+        } else if (status.remoteProfiling || Platform.getJDKVersionNumber() == Platform.JDK_19) {
+            classFileBytes = ClassBytesLoader.getClassFileBytes(classURL);
+        }
+        return classFileBytes;
+    }
+    
     private static void sendRootClassLoadedCommand(boolean doGetLoadedClasses) {
         if (doGetLoadedClasses) {
             getLoadedClasses(); // Otherwise we know loadedClassesArray has already been initialized
@@ -1404,13 +1446,7 @@ public class ProfilerInterface implements CommonConstants {
 
             loadedClassNames[idx] = name;
             loaders[idx] = loadedClassesLoaders[i];
-
-            if (loaders[idx] > 0) {
-                cachedClassFileBytes[idx] = getCachedClassFileBytes(loadedClassesArray[i]);
-            } else if (status.remoteProfiling) { // When we profile remotely, we need to send all available classes to the tool
-                cachedClassFileBytes[idx] = ClassBytesLoader.getClassFileBytes(loadedClassesArray[i].getName());
-            }
-
+            cachedClassFileBytes[idx] = getClassFileBytes(loadedClassesArray[i], loaders[idx]);
             idx++;
         }
         RootClassLoadedCommand cmd = new RootClassLoadedCommand(loadedClassNames, loaders, cachedClassFileBytes, idx,
@@ -1443,8 +1479,4 @@ public class ProfilerInterface implements CommonConstants {
             status.endTrans();
         }
     }
-    
-    public static ClassLoader getSystemClassLoader() {
-        return scl;
-    }
 }
