@@ -631,10 +631,13 @@ public class ProfilerServer extends Thread implements CommonConstants {
         status.remoteProfiling = remote;
         if (remote) {
             System.out.println(REMOTE_SESSION_MSG);
-            // This is to preload some classes that can otherwise be loaded at inappropriate time and cause class load hook firing.
-            ClassBytesLoader.preloadClasses();
+            ClassBytesLoader.preloadClasses(remote);
         } else {
             System.out.println(LOCAL_SESSION_MSG);
+            if (Platform.getJDKVersionNumber() == JDK_19) {
+                // This is to preload some classes that can otherwise be loaded at inappropriate time and cause class load hook firing.
+                ClassBytesLoader.preloadClasses(remote);
+            }
         }
     }
 
@@ -823,7 +826,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         }
     }
 
-    static void loadNativeLibrary(String fullJFluidPath, boolean fullPathToLibSpecified) {
+    public static void loadNativeLibrary(String fullJFluidPath, boolean fullPathToLibSpecified) {
         String libFullName = Platform.getAgentNativeLibFullName(fullJFluidPath, fullPathToLibSpecified, null, -1);
         System.load(libFullName);
     }
@@ -1582,8 +1585,8 @@ public class ProfilerServer extends Thread implements CommonConstants {
 
                 VMPropertiesResponse resp = new VMPropertiesResponse(Platform.getJavaVersionString(), 
                                                                      System.getProperty("java.class.path"), // NOI18N
-                                                                     System.getProperty("java.ext.dirs"), // NOI18N
-                                                                     System.getProperty("sun.boot.class.path"), // NOI18N
+                                                                     System.getProperty("java.ext.dirs", ""), // NOI18N
+                                                                     System.getProperty("sun.boot.class.path", ""), // NOI18N
                                                                      System.getProperty("user.dir"), // NOI18N
                                                                      status.jvmArguments, status.javaCommand,
                                                                      System.getProperty("os.name"), // NOI18N
