@@ -53,6 +53,9 @@ import org.netbeans.lib.profiler.global.Platform;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.file.DirectoryStream;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.text.MessageFormat;
 import java.util.*;
 import java.util.zip.ZipEntry;
@@ -312,6 +315,9 @@ public class MiscUtils implements CommonConstants {
             return JDK_18_STRING;
         } else if (outString.startsWith("1.9")) { // NOI18N
 
+            return JDK_19_STRING;
+        } else if (outString.startsWith("9")) { // NOI18N
+
             return JDK_19_STRING;
         } else {
             throw new IOException(VM_INCOMPATIBLE_MSG + printOutString);
@@ -517,19 +523,24 @@ public class MiscUtils implements CommonConstants {
     public static void deleteHeapTempFiles() {
         if (Platform.isWindows()) { // this is workaroud for JDK bug #6359560
 
-            File tempDir = new File(System.getProperty("java.io.tmpdir")); // NOI18N
-            File[] files = tempDir.listFiles();
+            try {
+                File tempDir = new File(System.getProperty("java.io.tmpdir")); // NOI18N
+                DirectoryStream<Path> files = Files.newDirectoryStream(tempDir.toPath());
 
-            // check that tempDir exists
-            if (files != null) {
-                for (int i = 0; i < files.length; i++) {
-                    File f = files[i];
-                    String fname = f.getName();
+                try {
+                    for (Path p : files) {
+                        String fname = p.toFile().getName();
 
-                    if (fname.startsWith("NBProfiler") && (fname.endsWith(".map") || fname.endsWith(".ref"))) { // NOI18N
-                        f.delete();
+                        if (fname.startsWith("NBProfiler") && (fname.endsWith(".map") || fname.endsWith(".ref") || fname.endsWith(".gc"))) { // NOI18N
+                            Files.delete(p);
+                        }
                     }
+                } finally {
+                    files.close();
                 }
+            } catch (IOException ex) {
+                System.err.println("deleteHeapTempFiles failed");
+                ex.printStackTrace();
             }
         }
     }
@@ -634,6 +645,8 @@ public class MiscUtils implements CommonConstants {
     private static boolean isSupported15or16or17or18or19orCvm(String jdkVersionString) {
         if (jdkVersionString.startsWith("1.9")) { // NOI18N
             return true;
+        } else if (jdkVersionString.startsWith("9")) { // NOI18N
+            return true;
         } else if (jdkVersionString.startsWith("1.8")) { // NOI18N
             return true;
         } else if (jdkVersionString.startsWith("1.7")) { // NOI18N
