@@ -72,6 +72,7 @@ import org.netbeans.modules.profiler.api.GoToSource;
 import org.netbeans.modules.profiler.api.icons.Icons;
 import org.netbeans.modules.profiler.api.ProfilerDialogs;
 import org.netbeans.modules.profiler.api.icons.ProfilerIcons;
+import org.netbeans.modules.profiler.heapwalk.details.api.DetailsSupport;
 import org.netbeans.modules.profiler.heapwalk.model.BrowserUtils;
 import org.netbeans.modules.profiler.heapwalk.ui.icons.HeapWalkerIcons;
 import org.openide.util.NbBundle;
@@ -214,7 +215,7 @@ public class OverviewController extends AbstractController {
         String oomeString = "";
         if (oome != null) {
             Instance thread = oome.getInstance();
-            String threadName = htmlize(getThreadName(thread));
+            String threadName = htmlize(getThreadName(heap, thread));
             String threadUrl = "<a href='"+ THREAD_URL_PREFIX + thread.getJavaClass().getName() + "/" + thread.getInstanceId() + "'>" + threadName + "</a>"; // NOI18N
             oomeString = "<br><br>" + LINE_PREFIX // NOI18N
                 + Bundle.OverviewController_OOMELabelString() + "<br>" + LINE_PREFIX // NOI18N
@@ -448,7 +449,7 @@ public class OverviewController extends AbstractController {
                     ThreadObjectGCRoot threadRoot = (ThreadObjectGCRoot)root;
                     Instance threadInstance = threadRoot.getInstance();
                     if (threadInstance != null) {
-                        String threadName = getThreadName(threadInstance);
+                        String threadName = getThreadName(h, threadInstance);
                         Boolean daemon = (Boolean)threadInstance.getValueOfField("daemon"); // NOI18N
                         Integer priority = (Integer)threadInstance.getValueOfField("priority"); // NOI18N
                         Long threadId = (Long)threadInstance.getValueOfField("tid");    // NOI18N
@@ -469,7 +470,7 @@ public class OverviewController extends AbstractController {
                             sb.append(" tid=").append(threadId);    // NOI18N
                         }
                         if (threadStatus != null) {
-                            State tState = sun.misc.VM.toThreadState(threadStatus.intValue());
+                            State tState = toThreadState(threadStatus.intValue());
                             sb.append(" ").append(tState);          // NOI18N
                         }
                         // --- Use this to enable VisualVM color scheme for threads dumps: ---
@@ -495,7 +496,7 @@ public class OverviewController extends AbstractController {
                                 } else {
                                     stackElHref = stackElementText;
                                 }
-                                sb.append("\tat ").append(stackElHref).append("<br>");  // NOI18N
+                                sb.append("    at ").append(stackElHref).append("<br>");  // NOI18N
                                 if (localsMap != null) {
                                     List<JavaFrameGCRoot> locals = localsMap.get(Integer.valueOf(i));
                                     
@@ -504,9 +505,9 @@ public class OverviewController extends AbstractController {
                                             Instance localInstance = localVar.getInstance();
                                             
                                             if (localInstance != null) {
-                                                sb.append("\t   Local Variable: ").append(printInstance(localInstance)).append("<br>"); // NOI18N
+                                                sb.append("       Local Variable: ").append(printInstance(localInstance)).append("<br>"); // NOI18N
                                             } else {
-                                                sb.append("\t   Unknown Local Variable<br>"); // NOI18N                                                
+                                                sb.append("       Unknown Local Variable<br>"); // NOI18N                                                
                                             }
                                         }
                                     }
@@ -525,47 +526,13 @@ public class OverviewController extends AbstractController {
         return stackTrace;
     }
 
-    private String getThreadName(final Instance threadInstance) {
+    private String getThreadName(final Heap heap, final Instance threadInstance) {
         Object threadName = threadInstance.getValueOfField("name");  // NOI18N
-        PrimitiveArrayInstance chars;
-        int offset = 0;
-        int len;
         
         if (threadName == null) {
             return "*null*"; // NOI18N
         }
-        if (threadName instanceof PrimitiveArrayInstance) {
-            chars = (PrimitiveArrayInstance)threadName;
-            len = chars.getLength();
-        } else {
-            Instance stringInstance = (Instance)threadName;
-            assert stringInstance.getJavaClass().getName().equals(String.class.getName());
-
-            chars = (PrimitiveArrayInstance) stringInstance.getValueOfField("value"); // NOI18N
-            if (chars != null) {
-                Integer oi = (Integer) stringInstance.getValueOfField("offset");  // NOI18N
-                Integer ci = (Integer) stringInstance.getValueOfField("count");   // NOI18N
-                if (oi != null) {
-                    offset = oi.intValue();
-                }
-                if (ci != null) {
-                    len = ci.intValue();
-                } else {
-                    len = chars.getLength();
-                }
-            } else {
-                return "*null*"; // NOI18N
-            }
-        }
-        List<String> charsList = chars.getValues();
-        List<String> stringList = charsList.subList(offset, offset+len);
-        char charArr[] = new char[stringList.size()];
-        int j = 0;
-
-        for(String ch:stringList) {
-            charArr[j++] = ch.charAt(0);
-        }
-        return new String(charArr);
+        return DetailsSupport.getDetailsString((Instance) threadName, heap);
     }
 
 
@@ -624,4 +591,37 @@ public class OverviewController extends AbstractController {
     private static String htmlize(String value) {
             return value.replace(">", "&gt;").replace("<", "&lt;");     // NOI18N
     }
+
+    /** taken from sun.misc.VM
+     * 
+     * Returns Thread.State for the given threadStatus
+     */
+    private static Thread.State toThreadState(int threadStatus) {
+        if ((threadStatus & JVMTI_THREAD_STATE_RUNNABLE) != 0) {
+            return State.RUNNABLE;
+        } else if ((threadStatus & JVMTI_THREAD_STATE_BLOCKED_ON_MONITOR_ENTER) != 0) {
+            return State.BLOCKED;
+        } else if ((threadStatus & JVMTI_THREAD_STATE_WAITING_INDEFINITELY) != 0) {
+            return State.WAITING;
+        } else if ((threadStatus & JVMTI_THREAD_STATE_WAITING_WITH_TIMEOUT) != 0) {
+            return State.TIMED_WAITING;
+        } else if ((threadStatus & JVMTI_THREAD_STATE_TERMINATED) != 0) {
+            return State.TERMINATED;
+        } else if ((threadStatus & JVMTI_THREAD_STATE_ALIVE) == 0) {
+            return State.NEW;
+        } else {
+            return State.RUNNABLE;
+        }
+    }
+
+    /* The threadStatus field is set by the VM at state transition
+     * in the hotspot implementation. Its value is set according to
+     * the JVM TI specification GetThreadState function.
+     */
+    private final static int JVMTI_THREAD_STATE_ALIVE = 0x0001;
+    private final static int JVMTI_THREAD_STATE_TERMINATED = 0x0002;
+    private final static int JVMTI_THREAD_STATE_RUNNABLE = 0x0004;
+    private final static int JVMTI_THREAD_STATE_BLOCKED_ON_MONITOR_ENTER = 0x0400;
+    private final static int JVMTI_THREAD_STATE_WAITING_INDEFINITELY = 0x0010;
+    private final static int JVMTI_THREAD_STATE_WAITING_WITH_TIMEOUT = 0x0020;
 }
