@@ -69,11 +69,13 @@ public final class ProfilerSupport {
     private static final String ORACLE_VM_VENDOR_PREFIX = "Oracle ";  // NOI18N
     private static final String APPLE_VM_VENDOR_PREFIX = "Apple ";  // NOI18N
     private static final String HP_VM_VENDOR_PREFIX = "\"Hewlett-Packard "; // NOI18N
+    private static final String AZUL_VM_VENDOR_PREFIX = "Azul ";  // NOI18N
     
     private static final String JAVA_RT_16_PREFIX = "1.6.0";  // NOI18N
     private static final String JAVA_RT_17_PREFIX = "1.7.0";  // NOI18N
     private static final String JAVA_RT_18_PREFIX = "1.8.0";  // NOI18N
     private static final String JAVA_RT_19_PREFIX = "1.9.0";  // NOI18N
+    private static final String JAVA_RT_9_PREFIX = "9";  // NOI18N
     
     private static ProfilerSupport instance;
     
@@ -312,10 +314,11 @@ public final class ProfilerSupport {
         String vmName = jvm.getVmName();
         String vmVendor = jvm.getVmVendor();
         
-        // VM has to be a HotSpot VM or OpenJDK by Sun Microsystems Inc. or Oracle Co. or Apple Inc. or Hewlett-Packard Co.
+        // VM has to be a HotSpot VM or OpenJDK by Sun Microsystems Inc. or Oracle Co. or Apple Inc. or Hewlett-Packard Co. or Azul Systems, Inc.
         return vmName != null && (vmName.startsWith(HOTSPOT_VM_NAME_PREFIX) || vmName.startsWith(OPENJDK_VM_NAME_PREFIX)) && 
                vmVendor != null && (vmVendor.startsWith(ORACLE_VM_VENDOR_PREFIX) || vmVendor.startsWith(SUN_VM_VENDOR_PREFIX) 
-                                 || vmVendor.startsWith(APPLE_VM_VENDOR_PREFIX) || vmVendor.startsWith(HP_VM_VENDOR_PREFIX));
+                                 || vmVendor.startsWith(APPLE_VM_VENDOR_PREFIX) || vmVendor.startsWith(HP_VM_VENDOR_PREFIX)
+                                 || vmVendor.startsWith(AZUL_VM_VENDOR_PREFIX));
     }
     
     static boolean classSharingBreaksProfiling(Application application) {
@@ -354,6 +357,8 @@ public final class ProfilerSupport {
                 return false;
             } else if (javaRTVersion.startsWith(JAVA_RT_19_PREFIX)) {
                 return false;
+            } else if (javaRTVersion.startsWith(JAVA_RT_9_PREFIX)) {
+                return false;
             }
         // OpenJDK -------------------------------------------------------------
         } else if(vmName.startsWith(OPENJDK_VM_NAME_PREFIX)) {
@@ -375,8 +380,9 @@ public final class ProfilerSupport {
             // OpenJDK 8 should be OK
             else if (javaRTVersion.startsWith(JAVA_RT_18_PREFIX)) {
                 return false;
-            }
-            else if (javaRTVersion.startsWith(JAVA_RT_19_PREFIX)) {
+            } else if (javaRTVersion.startsWith(JAVA_RT_19_PREFIX)) {
+                return false;
+            } else if (javaRTVersion.startsWith(JAVA_RT_9_PREFIX)) {
                 return false;
             }
         }
