@@ -33,6 +33,7 @@ import com.sun.tools.visualvm.application.Application;
 import com.sun.tools.visualvm.application.jvm.HeapHistogram;
 import com.sun.tools.visualvm.application.jvm.Jvm;
 import com.sun.tools.visualvm.application.jvm.JvmFactory;
+import com.sun.tools.visualvm.core.datasource.DataSource;
 import com.sun.tools.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
 import com.sun.tools.visualvm.core.datasupport.Stateful;
 import com.sun.tools.visualvm.core.datasupport.Utils;
@@ -85,7 +86,7 @@ import javax.swing.JToggleButton;
 import javax.swing.SwingUtilities;
 import org.netbeans.lib.profiler.common.ProfilingSettingsPresets;
 import org.netbeans.lib.profiler.results.cpu.CPUResultsSnapshot;
-import org.netbeans.lib.profiler.results.memory.AllocMemoryResultsSnapshot;
+import org.netbeans.lib.profiler.results.memory.SampledMemoryResultsSnapshot;
 import org.netbeans.modules.profiler.LoadedSnapshot;
 import org.netbeans.modules.profiler.ResultsManager;
 import org.openide.DialogDisplayer;
@@ -509,10 +510,13 @@ final class SamplerImpl {
                                     LOGGER.log(Level.WARNING, "Failed to save profiler snapshot for " + application, t); // NOI18N
                                 }
                                 if (ls != null) {
-                                    ProfilerSnapshot ps = ProfilerSnapshot.createSnapshot(ls.getFile(), application);
+                                    final ProfilerSnapshot ps = ProfilerSnapshot.createSnapshot(ls.getFile(), application);
                                     application.getRepository().addDataSource(ps);
-                                    if (openView)
-                                        DataSourceWindowManager.sharedInstance().openDataSource(ps);
+                                    if (openView) DataSource.EVENT_QUEUE.post(new Runnable() {
+                                        public void run() {
+                                            DataSourceWindowManager.sharedInstance().openDataSource(ps);
+                                        }
+                                    });
                                 }
                             }
                         });
@@ -682,7 +686,7 @@ final class SamplerImpl {
                                 DataOutputStream dos = null;
                                 try {
                                     long time = System.currentTimeMillis();
-                                    AllocMemoryResultsSnapshot snapshot = dumper.createSnapshot(time);
+                                    SampledMemoryResultsSnapshot snapshot = dumper.createSnapshot(time);
                                     if (snapshot == null) {
                                         DialogDisplayer.getDefault().notifyLater(new NotifyDescriptor.Message(
                                                 NbBundle.getMessage(SamplerImpl.class, "MSG_No_save_data_memory"), // NOI18N
@@ -690,7 +694,7 @@ final class SamplerImpl {
                                     } else {
                                         ls = new LoadedSnapshot(snapshot, ProfilingSettingsPresets.createMemoryPreset(), null, null);
                                         File file = Utils.getUniqueFile(application.getStorage().getDirectory(),
-                                                                        Long.toString(time),
+                                                                        ResultsManager.getDefault().getDefaultSnapshotFileName(ls),
                                                                         "." + ResultsManager.SNAPSHOT_EXTENSION); // NOI18N
                                         dos = new DataOutputStream(new FileOutputStream(file));
                                         ls.save(dos);
@@ -707,10 +711,13 @@ final class SamplerImpl {
                                     }
                                 }
                                 if (ls != null) {
-                                    ProfilerSnapshot ps = ProfilerSnapshot.createSnapshot(ls.getFile(), application);
+                                    final ProfilerSnapshot ps = ProfilerSnapshot.createSnapshot(ls.getFile(), application);
                                     application.getRepository().addDataSource(ps);
-                                    if (openView)
-                                        DataSourceWindowManager.sharedInstance().openDataSource(ps);
+                                    if (openView) DataSource.EVENT_QUEUE.post(new Runnable() {
+                                        public void run() {
+                                            DataSourceWindowManager.sharedInstance().openDataSource(ps);
+                                        }
+                                    });
                                 }
                             }
                         });
